SignInWithApplePlugin class

The web implementation of SignInWithApplePlatform.

This class implements the package:sign_in_with_apple functionality for the web.

Inheritance
  • Object
  • PlatformInterface
  • SignInWithApplePlatform
  • SignInWithApplePlugin

Constructors

SignInWithApplePlugin()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAppleIDCredential({required List<AppleIDAuthorizationScopes> scopes, WebAuthenticationOptions? webAuthenticationOptions, String? nonce, String? state}) Future<AuthorizationCredentialAppleID>
override
getCredentialState(String userIdentifier) Future<CredentialState>
inherited
getKeychainCredential() Future<AuthorizationCredentialPassword>
inherited
isAvailable() Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

registerWith(Registrar registrar) → void
Registers this class as the default instance of SignInWithApplePlatform.